summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorbolian <bolian@chromium.org>2014-09-30 19:41:54 -0700
committerCommit bot <commit-bot@chromium.org>2014-10-01 02:42:03 +0000
commit44ee3baf676fd5a05a76fbf9295686c1b7e2ec6f (patch)
tree3092ee87deb5682c30e4bd164dec3624d2689443
parentd95714f1db8dd1fe6138579db3971da4e947a5bf (diff)
downloadchromium_src-44ee3baf676fd5a05a76fbf9295686c1b7e2ec6f.zip
chromium_src-44ee3baf676fd5a05a76fbf9295686c1b7e2ec6f.tar.gz
chromium_src-44ee3baf676fd5a05a76fbf9295686c1b7e2ec6f.tar.bz2
Extend enable-data-reduction-proxy-dev about to beta channel
BUG=418338 Review URL: https://codereview.chromium.org/598543003 Cr-Commit-Position: refs/heads/master@{#297585}
-rw-r--r--chrome/browser/about_flags.cc3
1 files changed, 2 insertions, 1 deletions
diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
index 34614ac..03fa029 100644
--- a/chrome/browser/about_flags.cc
+++ b/chrome/browser/about_flags.cc
@@ -2064,8 +2064,9 @@ bool SkipConditionalExperiment(const Experiment& experiment,
}
#if defined(OS_ANDROID)
// enable-data-reduction-proxy-dev is only available for the Dev channel.
if (!strcmp("enable-data-reduction-proxy-dev", experiment.internal_name) &&
+ chrome::VersionInfo::GetChannel() != chrome::VersionInfo::CHANNEL_BETA &&
chrome::VersionInfo::GetChannel() != chrome::VersionInfo::CHANNEL_DEV) {
return true;
}
@@ -2064,8 +2064,9 @@ bool SkipConditionalExperiment(const Experiment& experiment,
}
#if defined(OS_ANDROID)
- // enable-data-reduction-proxy-dev is only available for the Dev channel.
+ // enable-data-reduction-proxy-dev is only available for the Dev/Beta channel.
if (!strcmp("enable-data-reduction-proxy-dev", experiment.internal_name) &&